Hi,

standard checking procedures on Debian revealed a spelling error:
"compatability" occurs a couple of times in the sources.

I'm a bit worried about the "kt70-compatibility" boolean flag, but
corrected its spelling for the Debian release.

Attached is a patch fixing all occurrences.

Regards

Markus Wanner
--- a/package/debian/rules
+++ b/package/debian/rules
@@ -5,7 +5,7 @@
 # Uncomment this to turn on verbose mode.
 #export DH_VERBOSE=1
 
-# This is the debhelper compatability version to use.
+# This is the debhelper compatibility version to use.
 export DH_COMPAT=3
 
 CFLAGS=-O2 $(DEBUGFLAGS)
--- a/src/Instrumentation/gps.cxx
+++ b/src/Instrumentation/gps.cxx
@@ -137,7 +137,7 @@
   _northSouthVelocity = _gpsNode->getChild("ns-velocity-msec", 0, true);
   
 // waypoints
-  // for compatability, alias selected course down to wp/wp[1]/desired-course-deg
+  // for compatibility, alias selected course down to wp/wp[1]/desired-course-deg
   SGPropertyNode* wp1Crs = _currentWayptNode->getChild("desired-course-deg", 0, true);
   wp1Crs->alias(_gpsNode->getChild("desired-course-deg", 0, true));
 
@@ -776,7 +776,7 @@
     return;
   }
  
-  // compatability feature - allow the route-manager / GPS to drive the
+  // compatibility feature - allow the route-manager / GPS to drive the
   // generic autopilot heading hold *in leg mode only* 
   
   bool drive = _mode == "leg";
--- a/src/Instrumentation/transponder.hxx
+++ b/src/Instrumentation/transponder.hxx
@@ -60,7 +60,7 @@
         KNOB_ALT
     };
     
-    // annunciators, for KT-70 compatability only
+    // annunciators, for KT-70 compatibility only
     // these should be replaced with conditionals in the instrument
     bool getFLAnnunciator() const;
     bool getAltAnnunciator() const;
--- a/src/Navaids/NavDataCache.cxx
+++ b/src/Navaids/NavDataCache.cxx
@@ -23,7 +23,7 @@
 # include "config.h"
 #endif
 
-// to ensure compatability between sqlite3_int64 and PositionedID,
+// to ensure compatibility between sqlite3_int64 and PositionedID,
 // force the type used by sqlite to match PositionedID explicitly
 #define SQLITE_INT64_TYPE int64_t
 #define SQLITE_UINT64_TYPE uint64_t

Attachment: signature.asc
Description: OpenPGP digital signature

------------------------------------------------------------------------------
LIMITED TIME SALE - Full Year of Microsoft Training For Just $49.99!
1,500+ hours of tutorials including VisualStudio 2012, Windows 8, SharePoint
2013, SQL 2012, MVC 4, more. BEST VALUE: New Multi-Library Power Pack includes
Mobile, Cloud, Java, and UX Design. Lowest price ever! Ends 9/22/13. 
http://pubads.g.doubleclick.net/gampad/clk?id=64545871&iu=/4140/ostg.clktrk
_______________________________________________
Flightgear-devel mailing list
Flightgear-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/flightgear-devel

Reply via email to
--- a/src/Instrumentation/instrument_mgr.cxx
+++ b/src/Instrumentation/instrument_mgr.cxx
@@ -177,10 +177,10 @@
 
         } else if (( name == "transponder" ) || ( name == "KT-70" )) {
             if  (name == "KT-70") {
-                SG_LOG(SG_INSTR, SG_WARN, "KT-70 legacy instrument compatability. "
+                SG_LOG(SG_INSTR, SG_WARN, "KT-70 legacy instrument compatibility. "
                        "Please update aircraft to use transponder directly");
-                // force configuration into compatability mode
-                node->setBoolValue("kt70-compatability", true);
+                // force configuration into compatibility mode
+                node->setBoolValue("kt70-compatibility", true);
             }
             set_subsystem( id, new Transponder( node ), 0.2 );
 
--- a/src/Instrumentation/transponder.cxx
+++ b/src/Instrumentation/transponder.cxx
@@ -56,7 +56,7 @@
 {
     _requiredBusVolts = node->getDoubleValue("bus-volts", 8.0);
     _altitudeSourcePath = node->getStringValue("encoder-path", "/instrumentation/altimeter");
-    _kt70Compat = node->getBoolValue("kt70-compatability", false);
+    _kt70Compat = node->getBoolValue("kt70-compatibility", false);
 }
 
 
@@ -142,7 +142,7 @@
                             &Transponder::getStandbyAnnunciator );
         _tiedProperties.Tie("annunciators/reply", this,
                             &Transponder::getReplyAnnunciator );
-    } // of kt70 backwards compatability
+    } // of kt70 backwards compatibility
 }
 
 void Transponder::unbind()